"use strict";
//  COPYRIGHT:       PrimeObjects Software Inc. (C) 2022 All Right Reserved
//  COMPANY URL:     https://www.primeobjects.com/
//  CONTACT:         developer@primeobjects.com
//
//  This source is subject to the PrimeObjects License Agreements.
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.HtmlEditorFloatEditToolbarContent = void 0;
var react_1 = __importDefault(require("react"));
var primeobjects_ui_web_basic_1 = require("primeobjects-ui-web-basic");
var primeobjects_helper_util_1 = require("primeobjects-helper-util");
var uuid_1 = require("primeobjects-helper-util/build/cjs/uuid");
var primary_color_1 = require("primeobjects-helper-ui/build/cjs/hooks/primary-color");
var HtmlEditorFloatEditToolbarContent = function (props) {
    var editor = props.editor, hideH1 = props.hideH1, hideH2 = props.hideH2, hideH3 = props.hideH3, hideH4 = props.hideH4, supportSourceCode = props.supportSourceCode, supportTooltips = props.supportTooltips;
    var primaryColor = (0, primary_color_1.usePrimaryColor)();
    var hasTooltip = editor.isActive("link") &&
        editor.getAttributes("link").href.indexOf("tooltip-") >= 0;
    var onChangeHeader = function (level) {
        editor.chain().focus().toggleHeading({ level: level }).run();
    };
    var onClickLink = function () {
        var hasLink = editor.isActive("link");
        if (hasLink) {
            editor.chain().focus().toggleLink().run();
        }
        else {
            var url = window.prompt("URL", editor.getAttributes("link").href);
            if (!(0, primeobjects_helper_util_1.isNonEmptyString)(url))
                return;
            editor
                .chain()
                .focus()
                .extendMarkRange("link")
                .setLink({ href: url })
                .run();
        }
    };
    var onClickTooltip = function () {
        if (editor.isActive("link") && !hasTooltip) {
            alert("Tooltip can not be applied to a web link.");
            return;
        }
        if (editor.isActive("link")) {
            props.onClickEditTooltip &&
                props.onClickEditTooltip(editor.getAttributes("link").href);
        }
        else {
            var id = (0, uuid_1.newGuid)();
            editor
                .chain()
                .focus()
                .extendMarkRange("link")
                .setLink({ href: "tooltip-".concat(id) })
                .run();
            props.onClickEditTooltip && props.onClickEditTooltip(id);
        }
    };
    var onRemoveTextForTooltip = function () {
        editor.chain().focus().toggleLink().run();
    };
    return (react_1.default.createElement("div", { className: "menu items-center" },
        !hideH1 && (react_1.default.createElement("div", { onClick: function () { return onChangeHeader(1); }, className: "menu-text ".concat(editor.isActive("heading", { level: 1 }) ? "active" : "") }, "H1")),
        !hideH2 && (react_1.default.createElement("div", { onClick: function () { return onChangeHeader(2); }, className: "menu-text ".concat(editor.isActive("heading", { level: 2 }) ? "active" : "") }, "H2")),
        !hideH3 && (react_1.default.createElement("div", { onClick: function () { return onChangeHeader(3); }, className: "menu-text ".concat(editor.isActive("heading", { level: 3 }) ? "active" : "") }, "H3")),
        !hideH4 && (react_1.default.createElement("div", { onClick: function () { return onChangeHeader(4); }, className: "menu-text ".concat(editor.isActive("heading", { level: 4 }) ? "active" : "") }, "H4")),
        react_1.default.createElement("div", { className: "menu-sp" }),
        react_1.default.createElement("div", { onClick: function () { return editor.chain().focus().toggleBold().run(); }, className: "menu-text menu-text-bold ".concat(editor.isActive("bold") ? "active" : "") }, "B"),
        react_1.default.createElement("div", { onClick: function () { return editor.chain().focus().toggleItalic().run(); }, className: "menu-text menu-text-italic ".concat(editor.isActive("italic") ? "active" : "") }, "I"),
        react_1.default.createElement("div", { onClick: function () { return editor.chain().focus().toggleStrike().run(); }, className: "menu-text menu-text-strikethrough ".concat(editor.isActive("strike") ? "active" : "") }, "T"),
        react_1.default.createElement("div", { className: "menu-sp" }),
        react_1.default.createElement(primeobjects_ui_web_basic_1.SVG, { src: "/icons/platform/html-editor/material-bullet-list.svg", onClick: function () { return editor.chain().focus().toggleBulletList().run(); }, className: "menu-icon", color: editor.isActive("bulletList")
                ? primaryColor["600"]
                : primeobjects_helper_util_1.COLORS.GRAY["900"] }),
        react_1.default.createElement(primeobjects_ui_web_basic_1.SVG, { src: "/icons/platform/html-editor/material-numbered-list.svg", onClick: function () { return editor.chain().focus().toggleOrderedList().run(); }, className: "menu-icon", color: editor.isActive("orderedList")
                ? primaryColor["600"]
                : primeobjects_helper_util_1.COLORS.GRAY["900"] }),
        react_1.default.createElement("div", { className: "menu-sp" }),
        supportSourceCode && (react_1.default.createElement(primeobjects_ui_web_basic_1.SVG, { src: "/icons/source-code.svg", onClick: function () {
                return editor.chain().focus().toggleCodeBlock().run();
            }, className: "menu-icon ".concat(editor.isActive("codeBlock") ? "active" : "") })),
        react_1.default.createElement(primeobjects_ui_web_basic_1.SVG, { src: "/icons/platform/html-editor/material-get-quote.svg", onClick: function () { return editor.chain().focus().toggleBlockquote().run(); }, className: "menu-icon ".concat(editor.isActive("blockquote") ? "active" : "") }),
        !hasTooltip && (react_1.default.createElement(primeobjects_ui_web_basic_1.SVG, { src: "/icons/platform/html-editor/material-link.svg", onClick: onClickLink, className: "menu-icon", color: editor.isActive("link")
                ? primaryColor["600"]
                : primeobjects_helper_util_1.COLORS.GRAY["900"] })),
        supportTooltips && (react_1.default.createElement(primeobjects_ui_web_basic_1.SVG, { src: "/icons/platform/html-editor/tooltip-on.svg", onClick: onClickTooltip, className: "menu-icon", color: hasTooltip ? primaryColor["600"] : primeobjects_helper_util_1.COLORS.GRAY["900"] })),
        hasTooltip && supportTooltips && (react_1.default.createElement(primeobjects_ui_web_basic_1.Tooltip, { title: "Clicking this button will detach the selected text from tooltip", color: primeobjects_helper_util_1.COLORS.RED["600"], textColor: primeobjects_helper_util_1.COLORS.WHITE },
            react_1.default.createElement(primeobjects_ui_web_basic_1.SVG, { src: "/icons/platform/html-editor/tooltip-off.svg", className: "menu-icon", color: primeobjects_helper_util_1.COLORS.RED["600"], onClick: onRemoveTextForTooltip })))));
};
exports.HtmlEditorFloatEditToolbarContent = HtmlEditorFloatEditToolbarContent;
exports.default = exports.HtmlEditorFloatEditToolbarContent;
//# sourceMappingURL=html-float-edit-toolbar-content.js.map