//  COPYRIGHT:       PrimeObjects Software Inc. (C) 2022 All Right Reserved
//  COMPANY URL:     https://www.primeobjects.com/
//  CONTACT:         developer@primeobjects.com
//
//  This source is subject to the PrimeObjects License Agreements.
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import React, { useEffect, useRef, useState } from "react";
import { isFunction, isNil, isArray, debounce } from "lodash";
import CSS from "primeobjects-ui-web-store/build/cjs/css";
import { isNonEmptyString } from "primeobjects-helper-util/build/cjs/core";
import HtmlEditorCode from "./html-code";
// import { HTML_EDITOR_CSS } from "./html-css";
// import { HTML_EDITOR_CODE_CSS } from "./html-code-css";
// import { THtmlEditorHighlightCustomButton } from "./html-editor-type";
import { HTML_EDITOR_CSS } from "./html-css";
import { HTML_EDITOR_CODE_CSS } from "./html-code-css";
import { getGlobalComponent } from "primeobjects-ui-web-application/build/cjs/util";
import HtmlEditorFloatEditToolbarInternal from "./html-float-edit-toolbar";
import HtmlEditorFloatInsertToolbarInternal from "./html-float-insert-toolbar";
import HtmlEditorFloatHighlightToolbarInternal from "./html-float-highlight-toolbar";
import { libTrackIsOn } from "primeobjects-helper-util";
var HtmlEditorFloatInsertToolbar = undefined;
var HtmlEditorFloatHighlightToolbar = undefined;
var HtmlEditorFloatEditToolbar = undefined;
// load specific languages only
// import lowlight from 'lowlight/lib/core'
// import javascript from 'highlight.js/lib/languages/javascript'
// lowlight.registerLanguage('javascript', javascript)
export var HtmlEditor = function (props) {
    var _a;
    if (!HtmlEditorFloatInsertToolbar) {
        console.log("Get global components in /html-editor.tsx");
        HtmlEditorFloatInsertToolbar = getGlobalComponent("HtmlEditorFloatInsertToolbar", HtmlEditorFloatInsertToolbarInternal);
        HtmlEditorFloatHighlightToolbar = getGlobalComponent("HtmlEditorFloatHighlightToolbar", HtmlEditorFloatHighlightToolbarInternal);
        HtmlEditorFloatEditToolbar = function (props) {
            var C = getGlobalComponent("HtmlEditorFloatEditToolbar", HtmlEditorFloatEditToolbarInternal);
            return React.createElement(C, __assign({}, props));
        };
    }
    var highlightCustomButtons = props.highlightCustomButtons, onHighlight = props.onHighlight, dependencies = props.dependencies;
    var useEditor = dependencies.useEditor, EditorContent = dependencies.EditorContent, ReactNodeViewRenderer = dependencies.ReactNodeViewRenderer, Typography = dependencies.Typography, Link = dependencies.Link, Image = dependencies.Image, Dropcursor = dependencies.Dropcursor, StarterKit = dependencies.StarterKit, CodeBlockLowlight = dependencies.CodeBlockLowlight, Highlight = dependencies.Highlight, Color = dependencies.Color, lowlight = dependencies.lowlight;
    var attributeName = !isNil(props.attributeName) && isNonEmptyString(props.attributeName)
        ? props.attributeName
        : "content";
    var placeholder = isNonEmptyString(props.placeholder)
        ? props.placeholder
        : "";
    var _b = useState(""), content = _b[0], setContent = _b[1];
    var _c = useState(props.tooltips ? props.tooltips : {}), tooltips = _c[0], setTooltips = _c[1];
    var recordId = props.recordId && props.recordId.length > 0 ? props.recordId : "";
    var id = "".concat(props.id, "-").concat(attributeName, "-").concat(recordId);
    var curEditor = useRef(null);
    var className = props.className ? props.className : "";
    var style = props.style ? props.style : {};
    var inputClassName = props.inputClassName ? props.inputClassName : "";
    var inputStyle = props.inputStyle ? props.inputStyle : {};
    var disabled = useRef(props.disabled == true);
    var readonly = useRef(props.readonly == true || props.disabled == true);
    var supportTooltips = props.supportTooltips !== false;
    var hideH1 = props.hideH1 == true;
    var hideH2 = props.hideH2 == true;
    var hideH3 = props.hideH3 == true;
    var hideH4 = props.hideH4 == true;
    var supportSourceCode = props.supportSourceCode == true;
    var supportHighlight = props.supportHighlight == true;
    var entityName = !isNil(props.entityName) && isNonEmptyString(props.entityName)
        ? props.entityName
        : "HTMLEditor";
    var highlightColors = !isNil(props.highlightColors) && isArray(props.highlightColors)
        ? props.highlightColors
        : [];
    // useEffect(() => {
    //     if (props.focus) {
    //         let htmlEditor: any = document.getElementsByClassName(`html-editor-${id}`);
    //         htmlEditor = htmlEditor.length > 0 && htmlEditor[0];
    //         let editorDivs = htmlEditor?.getElementsByClassName("ProseMirror");
    //         if (editorDivs && editorDivs.length > 0) editorDivs[0].focus();
    //     }
    // }, [props.focus]);
    useEffect(function () {
        setTooltips(props.tooltips ? props.tooltips : {});
    }, [props.tooltips]);
    // useEffect(() => {
    //     const newReadOnly = props.readonly == true || props.disabled == true;
    //     const newDisabled = props.disabled == true;
    //     if (disabled.current != newDisabled || readonly.current != newReadOnly) {
    //         disabled.current = newDisabled;
    //         readonly.current = newReadOnly;
    //         onInit("useEffect");
    //     }
    // }, [props.readonly, props.disabled]);
    useEffect(function () {
        var _a, _b, _c;
        var newContent = (_a = props.content) !== null && _a !== void 0 ? _a : "";
        if (newContent != content && ((_b = curEditor.current) === null || _b === void 0 ? void 0 : _b.commands)) {
            (_c = curEditor.current) === null || _c === void 0 ? void 0 : _c.commands.setContent(newContent);
        }
    }, [props.content, isNil((_a = curEditor.current) === null || _a === void 0 ? void 0 : _a.commands)]);
    var setPrevContent = function (content) {
        var o = document.getElementById("html-for-prev-".concat(id));
        if (o)
            o.innerHTML = content;
    };
    var getPrevContent = function () {
        var o = document.getElementById("html-for-prev-".concat(id));
        return o ? o.innerHTML : "";
    };
    // const onInit = (trigger: string) => {
    //     if (libTrackIsOn()) console.log({ trigger });
    //     let htmlEditor: any = document.getElementsByClassName(`html-editor-${id}`);
    //     htmlEditor = htmlEditor.length > 0 && htmlEditor[0];
    //     let editorDivs = htmlEditor?.getElementsByClassName("ProseMirror");
    //     if (editorDivs && editorDivs.length > 0) {
    //         if (readonly.current) {
    //             editorDivs[0].setAttribute("contenteditable", "false");
    //         } else {
    //             editorDivs[0].setAttribute("contenteditable", "true");
    //         }
    //         //remove empty br
    //         const fieldEmptyBr: any = htmlEditor?.getElementsByClassName(`ProseMirror-trailingBreak`);
    //         for (let i = 0; i < fieldEmptyBr.length; i++) {
    //             if (fieldEmptyBr[i].tagName == "BR" && fieldEmptyBr[i].parentElement.children.length == 1) {
    //                 fieldEmptyBr[i].parentElement.remove();
    //             }
    //         }
    //     }
    // };
    var handleImageTail = function (editor, htmlEditor, html) {
        var _a;
        if (!htmlEditor)
            return;
        var htmlEditorElem = htmlEditor.getElementsByClassName("ProseMirror");
        var lastChildren = htmlEditorElem.length > 0 && htmlEditorElem[0].children.length > 0
            ? htmlEditorElem[0].children[htmlEditorElem[0].children.length - 1]
            : null;
        if ((lastChildren === null || lastChildren === void 0 ? void 0 : lastChildren.tagName) == "IMG") {
            //in this case we need to ensure a new line below img
            (_a = editor === null || editor === void 0 ? void 0 : editor.commands) === null || _a === void 0 ? void 0 : _a.setContent("".concat(html, "<p></p>"));
        }
    };
    var onEvent = function (editor, action, info) {
        var _a, _b, _c, _d, _e, _f, _g;
        var html = editor.getHTML();
        var event = info === null || info === void 0 ? void 0 : info.event;
        if (libTrackIsOn())
            console.log({ HtmlEditorOnEvent: { action: action, info: info }, html: html });
        var htmlEditor = document.getElementsByClassName("html-editor-".concat(id));
        htmlEditor = htmlEditor.length > 0 && htmlEditor[0];
        if (action == "init" &&
            htmlEditor &&
            htmlEditor.className.indexOf("is-initialized") < 0) {
            if (!isNonEmptyString(html) ||
                html == "<p></p>" ||
                html == "<p></p><p></p>") {
                htmlEditor.className = "".concat(htmlEditor.className, " is-initialized is-placeholder html-editor-").concat(id, "-is-placeholder is-initialized");
                (_a = editor === null || editor === void 0 ? void 0 : editor.commands) === null || _a === void 0 ? void 0 : _a.setContent("<p>".concat(placeholder, "</p>"));
            }
            else {
                //clean up a special camera icon thing
                (_b = editor === null || editor === void 0 ? void 0 : editor.commands) === null || _b === void 0 ? void 0 : _b.setContent(html.replace(/<p>📷<\/p>/g, ""));
                htmlEditor.className = "".concat(htmlEditor.className, " is-initialized")
                    .replace("html-editor-".concat(id, "-is-placeholder"), "")
                    .replace("is-placeholder", "")
                    .trim();
            }
            props.getEditor && props.getEditor(editor);
        }
        if (action == "blur" &&
            !(((_d = (_c = event === null || event === void 0 ? void 0 : event.relatedTarget) === null || _c === void 0 ? void 0 : _c.className) === null || _d === void 0 ? void 0 : _d.indexOf("html-editor-insert-toolbar-button")) >= 0) &&
            (html == "<p></p><p></p>" || html == "<p></p>")) {
            if (htmlEditor)
                htmlEditor.className = "".concat(htmlEditor.className, " is-placeholder html-editor-").concat(id, "-is-placeholder");
            (_e = editor === null || editor === void 0 ? void 0 : editor.commands) === null || _e === void 0 ? void 0 : _e.setContent("<p>".concat(placeholder, "</p>"));
        }
        if (action == "focus" && !readonly.current) {
            if (htmlEditor)
                htmlEditor.className = htmlEditor.className
                    .replace("html-editor-".concat(id, "-is-placeholder"), "")
                    .replace("is-placeholder", "")
                    .trim();
            if (html == "<p>".concat(placeholder, "</p>")) {
                (_f = editor === null || editor === void 0 ? void 0 : editor.commands) === null || _f === void 0 ? void 0 : _f.setContent("<p></p>");
            }
            else {
                handleImageTail(editor, htmlEditor, html);
            }
        }
        if (action == "transaction" && !readonly.current) {
            if (htmlEditor && html != "<p>".concat(placeholder, "</p>")) {
                htmlEditor.className = htmlEditor.className
                    .replace("html-editor-".concat(id, "-is-placeholder"), "")
                    .replace("is-placeholder", "")
                    .trim();
            }
        }
        if ((action == "selection" || action == "focus") &&
            htmlEditor &&
            !readonly.current) {
            if (html == "<p></p>") {
                if (htmlEditor.className.indexOf("is-empty") < 0)
                    htmlEditor.className = "".concat(htmlEditor.className, " is-empty");
            }
            else {
                if (htmlEditor.className.indexOf("is-empty") > 0)
                    htmlEditor.className = htmlEditor.className.replace("is-empty", "");
            }
        }
        if (action == "update") {
            var prevContent = getPrevContent();
            if (htmlEditor)
                htmlEditor.className = htmlEditor.className
                    .replace("html-editor-".concat(id, "-is-placeholder"), "")
                    .replace("is-placeholder", "")
                    .trim();
            if (readonly.current &&
                ((info === null || info === void 0 ? void 0 : info.type) == "paste" || (info === null || info === void 0 ? void 0 : info.type) == "cut")) {
                //rollback
                (_g = editor === null || editor === void 0 ? void 0 : editor.commands) === null || _g === void 0 ? void 0 : _g.setContent(prevContent);
            }
            else {
                onSyncContent(html);
            }
            // document.getElementById(`html-for-sync-${id}`)?.click();
        }
        handleImageTail(editor, htmlEditor, html);
    };
    var editor = useEditor({
        content: content,
        extensions: [
            StarterKit,
            Highlight.configure({ multicolor: true }),
            Color,
            Link.configure({
                openOnClick: false
            }),
            Image,
            Dropcursor,
            Typography,
            CodeBlockLowlight.extend({
                addNodeView: function () {
                    return ReactNodeViewRenderer(function (props) {
                        return (React.createElement(HtmlEditorCode, __assign({}, props, { readonly: readonly.current })));
                    });
                }
            }).configure({ lowlight: lowlight })
        ],
        onBeforeCreate: function () {
            //const { editor } = createParams;
            editor;
        },
        onCreate: function (props) {
            var _a;
            var editor = props.editor;
            //the line below has to be done here, do not move inside onEvent
            //document.getElementById(`html-for-init-${id}`)?.click();
            curEditor.current = editor;
            (_a = editor === null || editor === void 0 ? void 0 : editor.commands) === null || _a === void 0 ? void 0 : _a.setContent(content);
            onEvent(editor, "init");
        },
        onUpdate: function (updateParams) {
            var _a;
            var editor = updateParams.editor;
            var transaction = updateParams.transaction;
            //const transaction: Record<string, any> = updateParams?.transaction;
            var uiEvent = (_a = transaction === null || transaction === void 0 ? void 0 : transaction.meta) === null || _a === void 0 ? void 0 : _a.uiEvent;
            onEvent(editor, "update", { type: uiEvent ? uiEvent : "default" });
        },
        onSelectionUpdate: function (props) {
            var editor = props.editor;
            onEvent(editor, "selection");
            // editor.chain().focus().setImage({ src: url }).run()
            // The selection has changed.
        },
        onTransaction: function (props) {
            var editor = props.editor;
            onEvent(editor, "transaction");
            // The editor state has changed.
        },
        onFocus: function (props) {
            var editor = props.editor;
            onEvent(editor, "focus");
        },
        onBlur: function (props) {
            var editor = props.editor, event = props.event;
            onEvent(editor, "blur", { event: event });
        },
        onDestroy: function () {
            //console.log({ HTMLEditoronDestroy: true });
            // The editor is being destroyed.
        }
    });
    // const onInitContent = (editor: any) => {
    //     editor?.commands?.setContent(content);
    // };
    var onSyncContent = debounce(function (newContent) {
        if (newContent == "" || newContent == "<p></p>")
            newContent = "<p></p><p></p>";
        if (content != newContent) {
            console.log("content debounce");
            setPrevContent(newContent);
            setContent(newContent);
            props.onChange &&
                props.onChange(isNonEmptyString(newContent) ? newContent : "", tooltips);
        }
    }, 300);
    var onUpdateTooltips = function (editor, tooltips) {
        if (isFunction(props.onChange))
            props.onChange(editor === null || editor === void 0 ? void 0 : editor.getHTML(), tooltips);
    };
    return (React.createElement(React.Fragment, null,
        React.createElement(CSS, { id: "html-editor-css", content: HTML_EDITOR_CSS }),
        React.createElement(CSS, { id: "html-editor-code-css", content: HTML_EDITOR_CODE_CSS }),
        React.createElement("div", { className: "w-full html-editor article html-editor-".concat(id, " ").concat(readonly.current ? "readonly-true" : "readonly-false", " ").concat(className), style: style },
            editor && (React.createElement(HtmlEditorFloatInsertToolbar, { recordId: recordId, entityName: entityName, attributeName: attributeName, editor: editor, wrapperClassName: !readonly ? "" : "hidden" })),
            editor && (React.createElement(HtmlEditorFloatEditToolbar, { editor: editor, hideH1: hideH1 || readonly.current, hideH2: hideH2 || readonly.current, hideH3: hideH3 || readonly.current, hideH4: hideH4 || readonly.current, wrapperClassName: !disabled.current &&
                    (!readonly.current ||
                        (readonly.current && supportHighlight))
                    ? ""
                    : "hidden", supportHighlight: supportHighlight, supportSourceCode: supportSourceCode && !readonly.current, supportTooltips: supportTooltips, tooltips: tooltips, tooltipEditorProps: {
                    id: "".concat(id, "-tooltip"),
                    entityName: entityName,
                    attributeName: attributeName,
                    recordId: recordId,
                    hideH1: props.hideH1,
                    hideH2: props.hideH2,
                    hideH3: props.hideH3,
                    hideH4: props.hideH4,
                    supportHighlight: props.supportHighlight,
                    supportSourceCode: props.supportSourceCode,
                    highlightCustomButtons: highlightCustomButtons,
                    highlightColors: props.highlightColors
                }, onUpdateTooltips: function (tooltips) {
                    return onUpdateTooltips(editor, tooltips);
                } })),
            editor && (React.createElement(HtmlEditorFloatHighlightToolbar, { editor: editor, colors: highlightColors, customButtons: highlightCustomButtons, onHighlight: onHighlight, wrapperClassName: supportHighlight && !disabled.current
                    ? ""
                    : "hidden" })),
            React.createElement(EditorContent, { editor: editor, className: "editor ".concat(readonly.current ? "readonly-true" : "readonly-false", " ").concat(inputClassName), style: inputStyle })),
        React.createElement("div", { id: "html-for-prev-".concat(id), className: "hidden" })));
};
HtmlEditor.displayName = "HtmlEditor";
export default HtmlEditor;
//# sourceMappingURL=html-editor.js.map