//  COPYRIGHT:       PrimeObjects Software Inc. (C) 2022 All Right Reserved
//  COMPANY URL:     https://www.primeobjects.com/
//  CONTACT:         developer@primeobjects.com
//
//  This source is subject to the PrimeObjects License Agreements.
import React from "react";
import { SVG, Tooltip } from "primeobjects-ui-web-basic";
import { COLORS, isNonEmptyString } from "primeobjects-helper-util";
import { newGuid } from "primeobjects-helper-util/build/cjs/uuid";
import { usePrimaryColor } from "primeobjects-helper-ui/build/cjs/hooks/primary-color";
export var HtmlEditorFloatEditToolbarContent = function (props) {
    var editor = props.editor, hideH1 = props.hideH1, hideH2 = props.hideH2, hideH3 = props.hideH3, hideH4 = props.hideH4, supportSourceCode = props.supportSourceCode, supportTooltips = props.supportTooltips;
    var primaryColor = usePrimaryColor();
    var hasTooltip = editor.isActive("link") &&
        editor.getAttributes("link").href.indexOf("tooltip-") >= 0;
    var onChangeHeader = function (level) {
        editor.chain().focus().toggleHeading({ level: level }).run();
    };
    var onClickLink = function () {
        var hasLink = editor.isActive("link");
        if (hasLink) {
            editor.chain().focus().toggleLink().run();
        }
        else {
            var url = window.prompt("URL", editor.getAttributes("link").href);
            if (!isNonEmptyString(url))
                return;
            editor
                .chain()
                .focus()
                .extendMarkRange("link")
                .setLink({ href: url })
                .run();
        }
    };
    var onClickTooltip = function () {
        if (editor.isActive("link") && !hasTooltip) {
            alert("Tooltip can not be applied to a web link.");
            return;
        }
        if (editor.isActive("link")) {
            props.onClickEditTooltip &&
                props.onClickEditTooltip(editor.getAttributes("link").href);
        }
        else {
            var id = newGuid();
            editor
                .chain()
                .focus()
                .extendMarkRange("link")
                .setLink({ href: "tooltip-".concat(id) })
                .run();
            props.onClickEditTooltip && props.onClickEditTooltip(id);
        }
    };
    var onRemoveTextForTooltip = function () {
        editor.chain().focus().toggleLink().run();
    };
    return (React.createElement("div", { className: "menu items-center" },
        !hideH1 && (React.createElement("div", { onClick: function () { return onChangeHeader(1); }, className: "menu-text ".concat(editor.isActive("heading", { level: 1 }) ? "active" : "") }, "H1")),
        !hideH2 && (React.createElement("div", { onClick: function () { return onChangeHeader(2); }, className: "menu-text ".concat(editor.isActive("heading", { level: 2 }) ? "active" : "") }, "H2")),
        !hideH3 && (React.createElement("div", { onClick: function () { return onChangeHeader(3); }, className: "menu-text ".concat(editor.isActive("heading", { level: 3 }) ? "active" : "") }, "H3")),
        !hideH4 && (React.createElement("div", { onClick: function () { return onChangeHeader(4); }, className: "menu-text ".concat(editor.isActive("heading", { level: 4 }) ? "active" : "") }, "H4")),
        React.createElement("div", { className: "menu-sp" }),
        React.createElement("div", { onClick: function () { return editor.chain().focus().toggleBold().run(); }, className: "menu-text menu-text-bold ".concat(editor.isActive("bold") ? "active" : "") }, "B"),
        React.createElement("div", { onClick: function () { return editor.chain().focus().toggleItalic().run(); }, className: "menu-text menu-text-italic ".concat(editor.isActive("italic") ? "active" : "") }, "I"),
        React.createElement("div", { onClick: function () { return editor.chain().focus().toggleStrike().run(); }, className: "menu-text menu-text-strikethrough ".concat(editor.isActive("strike") ? "active" : "") }, "T"),
        React.createElement("div", { className: "menu-sp" }),
        React.createElement(SVG, { src: "/icons/platform/html-editor/material-bullet-list.svg", onClick: function () { return editor.chain().focus().toggleBulletList().run(); }, className: "menu-icon", color: editor.isActive("bulletList")
                ? primaryColor["600"]
                : COLORS.GRAY["900"] }),
        React.createElement(SVG, { src: "/icons/platform/html-editor/material-numbered-list.svg", onClick: function () { return editor.chain().focus().toggleOrderedList().run(); }, className: "menu-icon", color: editor.isActive("orderedList")
                ? primaryColor["600"]
                : COLORS.GRAY["900"] }),
        React.createElement("div", { className: "menu-sp" }),
        supportSourceCode && (React.createElement(SVG, { src: "/icons/source-code.svg", onClick: function () {
                return editor.chain().focus().toggleCodeBlock().run();
            }, className: "menu-icon ".concat(editor.isActive("codeBlock") ? "active" : "") })),
        React.createElement(SVG, { src: "/icons/platform/html-editor/material-get-quote.svg", onClick: function () { return editor.chain().focus().toggleBlockquote().run(); }, className: "menu-icon ".concat(editor.isActive("blockquote") ? "active" : "") }),
        !hasTooltip && (React.createElement(SVG, { src: "/icons/platform/html-editor/material-link.svg", onClick: onClickLink, className: "menu-icon", color: editor.isActive("link")
                ? primaryColor["600"]
                : COLORS.GRAY["900"] })),
        supportTooltips && (React.createElement(SVG, { src: "/icons/platform/html-editor/tooltip-on.svg", onClick: onClickTooltip, className: "menu-icon", color: hasTooltip ? primaryColor["600"] : COLORS.GRAY["900"] })),
        hasTooltip && supportTooltips && (React.createElement(Tooltip, { title: "Clicking this button will detach the selected text from tooltip", color: COLORS.RED["600"], textColor: COLORS.WHITE },
            React.createElement(SVG, { src: "/icons/platform/html-editor/tooltip-off.svg", className: "menu-icon", color: COLORS.RED["600"], onClick: onRemoveTextForTooltip })))));
};
export default HtmlEditorFloatEditToolbarContent;
//# sourceMappingURL=html-float-edit-toolbar-content.js.map