//  COPYRIGHT:       PrimeObjects Software Inc. (C) 2022 All Right Reserved
//  COMPANY URL:     https://www.primeobjects.com/
//  CONTACT:         developer@primeobjects.com
//
//  This source is subject to the PrimeObjects License Agreements.
import React from "react";
import { SVG } from "primeobjects-ui-web-basic";
import { newGuid } from "primeobjects-helper-util";
import { FloatingMenu } from "@tiptap/react";
// import FloatingMenu from "./extension-floating-menu";
import { each } from "lodash";
import { Uploader } from "primeobjects-ui-web-application/build/cjs/controls/uploader";
import { usePrimaryColor } from "primeobjects-helper-ui/build/cjs/hooks/primary-color";
var FLOAT_MENU_CLASSNAMES = "html-editor-insert-toolbar-button p-1 border border-gray-900 flex content-center items-center bg-white mr-2 text-gray-900 font-semibold";
export var HtmlEditorFloatInsertToolbar = function (props) {
    var editor = props.editor, attributeName = props.attributeName, recordId = props.recordId, entityName = props.entityName;
    var primaryColor = usePrimaryColor();
    var onUploadPhoto = function (photoInfo) {
        var src = photoInfo.cfSignedResult.signedUrl;
        var rawSrc = photoInfo.cfSignedRawResult.signedUrl;
        editor.commands.setImage({ src: src });
        each(document.getElementsByTagName("img"), function (img) {
            if (img.src == src) {
                img.onerror = function () {
                    this.rawSrc = rawSrc;
                    this.src = rawSrc;
                };
            }
        });
    };
    return (React.createElement(FloatingMenu, { editor: editor, className: props.wrapperClassName },
        React.createElement("button", { className: FLOAT_MENU_CLASSNAMES, style: editor.isActive("heading", { level: 2 }) ? { color: primaryColor["500"] } : {}, onClick: function () { return editor.chain().focus().toggleHeading({ level: 2 }).run(); } }, "H2"),
        React.createElement("button", { className: FLOAT_MENU_CLASSNAMES, style: editor.isActive("heading", { level: 3 }) ? { color: primaryColor["500"] } : {}, onClick: function () { return editor.chain().focus().toggleHeading({ level: 3 }).run(); } }, "H3"),
        React.createElement("button", { className: FLOAT_MENU_CLASSNAMES, onClick: function () { return editor.chain().focus().toggleBulletList().run(); } },
            React.createElement(SVG, { src: "/icons/platform/html-editor/material-bullet-list.svg", size: 20 })),
        React.createElement("button", { className: FLOAT_MENU_CLASSNAMES, onClick: function () { return editor.chain().focus().toggleOrderedList().run(); } },
            React.createElement(SVG, { src: "/icons/platform/html-editor/material-numbered-list.svg", size: 20 })),
        React.createElement("button", { className: FLOAT_MENU_CLASSNAMES },
            React.createElement(Uploader, { iconStyle: { width: 20, height: 20 }, hideLabel: true, entityName: entityName, attributeName: attributeName, fileType: "Photo", onSuccess: onUploadPhoto, recordId: recordId, fileNamePrefix: newGuid(), signedUrlFormat: "webp", uiFormat: "icon", iconUrl: "/icons/platform/image.svg", wrapperStyle: { width: 20, height: 20, border: "none" } }))));
};
export default HtmlEditorFloatInsertToolbar;
//# sourceMappingURL=html-float-insert-toolbar.js.map